package io.better.toutiao.api.advertisingdelivery;

import io.better.toutiao.dto.advertisingdelivery.plan.AdvertisingPlanDTO;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @author better create in 2019-04-28 16:27
 */
@FeignClient(value = "https://ad.toutiao.com/open_api/2", url = "/ad")
public interface AdvertisingPlanApi {

    /**
     * 广告投放-获取某广告的广告计划
     *
     * @param accessToken 访问凭证
     * @param page        当前页
     * @param pageSize    每页记录数
     * @param filtering   过滤字段
     * @param fields      查询字段
     * @return
     */
    @GetMapping(value = "/get")
    List<Object> getAdvertisingPlan(@RequestHeader("Access-Token") String accessToken,
                                    @RequestParam("advertiser_id") Long advertiserId,
                                    @RequestParam(value = "page", defaultValue = "1", required = false) Integer page,
                                    @RequestParam(value = "page_size", defaultValue = "20", required = false) Integer pageSize,
                                    @RequestParam(value = "filtering", required = false) Map<String, Object> filtering,
                                    @RequestParam(value = "fields", required = false) String[] fields);


    /**
     * 广告投放-为某广告创建广告计划
     *
     * @param accessToken        访问凭证
     * @param advertisingPlanDTO 更新对象
     * @return
     */
    @PostMapping(value = "https://ad.toutiao.com/open_api/2/ad/create/")
    List<Object> createAdvertisingPlan(@RequestHeader("Access-Token") String accessToken,
                                       @RequestBody AdvertisingPlanDTO advertisingPlanDTO
    );
}
